GenerateImageResult: Generate Image Result

GenerateImageResultR Documentation

Generate Image Result

Description

Result object returned by image generation and editing models.

Public fields

images

Generated image artifacts.

text

Optional textual companion output.

usage

Usage information from the provider.

finish_reason

Reason the model stopped generating.

warnings

Any warnings from the model.

raw_response

The raw response from the provider API.

Methods

Public methods


Method new()

Initialize a GenerateImageResult object.

Usage
GenerateImageResult$new(
  images = NULL,
  text = NULL,
  usage = NULL,
  finish_reason = NULL,
  warnings = NULL,
  raw_response = NULL
)
Arguments
images

Generated image artifacts.

text

Optional text output.

usage

Usage information.

finish_reason

Finish reason.

warnings

Warnings.

raw_response

Raw provider response.


Method print()

Print method for GenerateImageResult.

Usage
GenerateImageResult$print()

Method clone()

The objects of this class are cloneable with this method.

Usage
GenerateImageResult$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


aisdk documentation built on May 29, 2026, 9:07 a.m.