| agent_library | R Documentation |
Factory functions for creating standard library agents for common tasks. These agents are pre-configured with appropriate system prompts and tools for their respective specializations.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.