analyze_r_package: Analyze R Package for Skill Creation
Description
Introspects an installed R package to understand its capabilities, exported functions,
and documentation. This is used by the Skill Architect to "learn" a package.
Usage
analyze_r_package(package)
Value
A string summary of the package.
Arguments
- package
Name of the package to analyze.