View source: R/utils_console.R
| analyze_tool_failures | R Documentation |
Analyzes a list of tool results and counts failures per tool.
analyze_tool_failures(tool_results)
tool_results |
List of tool result objects from a generation |
Named integer vector with failure counts per tool name
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.