capture_r_execution: Capture the output, messages, and value of evaluating an...

View source: R/utils_capture.R

capture_r_executionR Documentation

Capture the output, messages, and value of evaluating an expression

Description

Part of the companion-package extension API (used by aisdk.datatools).

Usage

capture_r_execution(expr, envir = parent.frame(), auto_print_value = FALSE)

Arguments

expr

Expression to evaluate.

envir

Environment in which to evaluate expr.

auto_print_value

Whether to auto-print the resulting value.

Value

A list describing the captured execution (output, value, status).


aisdk documentation built on May 29, 2026, 9:07 a.m.