clear_error_context: Clear Error Context for ask_ai()

View source: R/ask_ai.R

clear_error_contextR Documentation

Clear Error Context for ask_ai()

Description

Clears the tracked error and warning context used by ask_ai(). This is useful when you want to start a fresh debugging session without stale error messages from previous operations.

Usage

clear_error_context()

Value

Invisibly returns TRUE.

Examples

## Not run: 
# Clear stale errors before starting a new debugging session
clear_error_context()
ask_ai()

## End(Not run)

aisdk documentation built on May 29, 2026, 9:07 a.m.