console: Console Chat: Interactive REPL

consoleR Documentation

Console Chat: Interactive REPL

Description

Interactive terminal chat interface for ChatSession. Provides a REPL (Read-Eval-Print Loop) for conversing with LLMs. By default, enables an intelligent terminal agent that can execute commands, manage files, and run R code through natural language.


aisdk documentation built on May 29, 2026, 9:07 a.m.