content_text: Create Text Content

View source: R/multimodal.R

content_textR Documentation

Create Text Content

Description

Creates a text content object for a multimodal message. This is kept for backward compatibility and returns the provider-neutral text block used by multimodal providers.

Usage

content_text(text)

Arguments

text

The text string.

Value

A list representing the text content.


aisdk documentation built on May 29, 2026, 9:07 a.m.