View source: R/context_query_tools.R
| create_context_query_tools | R Documentation |
Create ordinary Tool objects for searching handles, resolving handles,
peeking live R objects, and launching bounded child sessions.
create_context_query_tools(session = NULL)
session |
Optional |
A list of Tool objects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.