Learn R Programming

aisdk (version 1.1.0)

create_feishu_event_processor: Create a Feishu Event Processor

Description

Create a plain event processor for Feishu events that already arrived through an authenticated ingress such as the official long-connection SDK.

Usage

create_feishu_event_processor(runtime)

Value

A function (payload) that processes one Feishu event payload.

Arguments

runtime

A ChannelRuntime with a Feishu adapter registered.