| create_invalid_tool_handler | R Documentation |
Creates a special "invalid" tool that handles unrecognized or failed tool calls gracefully. This allows the system to continue operating and provide meaningful feedback to the LLM.
create_invalid_tool_handler()
A Tool object for handling invalid tool calls.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.