create_r_code_tool: Create R Code Interpreter Tool

View source: R/sandbox.R

create_r_code_toolR Documentation

Create R Code Interpreter Tool

Description

Creates a meta-tool (execute_r_code) backed by a SandboxManager. This single tool replaces all individual tools for the LLM, enabling batch execution, data filtering, and local computation.

Usage

create_r_code_tool(sandbox)

Arguments

sandbox

A SandboxManager object.

Value

A Tool object named execute_r_code.


aisdk documentation built on May 29, 2026, 9:07 a.m.