create_sandbox_system_prompt: Create Sandbox System Prompt

View source: R/sandbox.R

create_sandbox_system_promptR Documentation

Create Sandbox System Prompt

Description

Generates a system prompt section that instructs the LLM how to use the R code sandbox effectively.

Usage

create_sandbox_system_prompt(sandbox)

Arguments

sandbox

A SandboxManager object.

Value

A character string to append to the system prompt.


aisdk documentation built on May 29, 2026, 9:07 a.m.