create_semantic_adapter_registry: Create a Semantic Adapter Registry

View source: R/semantic_adapter.R

create_semantic_adapter_registryR Documentation

Create a Semantic Adapter Registry

Description

Create a registry for semantic adapters. The registry resolves the highest priority adapter whose supports(obj) predicate matches an object.

Usage

create_semantic_adapter_registry(adapters = list())

Arguments

adapters

Optional list of adapters to register on creation.

Details

This constructor is part of the public semantic adapter authoring API for extension packages.

The returned registry exposes register(), unregister(), get_adapter(), list_adapters(), register_workflow_hint(), list_workflow_hints(), resolve_workflow_hint(), and resolve() methods.

Value

A SemanticAdapterRegistry object.


aisdk documentation built on May 29, 2026, 9:07 a.m.