Learn R Programming

aisdk (version 1.1.0)

create_stream_renderer: Create a Stream Renderer

Description

Creates an environment to manage the state of a streaming response, including thinking indicators and tool execution status.

Usage

create_stream_renderer()

Arguments

Value

A list of functions for rendering.