get_last_error_for_tool: Get Last Error for Tool

View source: R/utils_console.R

get_last_error_for_toolR Documentation

Get Last Error for Tool

Description

Retrieves the error message from the last failure of a specific tool.

Usage

get_last_error_for_tool(tool_results, tool_name)

Arguments

tool_results

List of tool result objects

tool_name

Name of the tool to find the last error for

Value

Character string with the error message, or NULL if not found


aisdk documentation built on May 29, 2026, 9:07 a.m.