get_model_info: Get Full Model Info

View source: R/utils_models.R

get_model_infoR Documentation

Get Full Model Info

Description

Returns the full metadata for a single model as a list. Useful for framework internals to auto-configure parameters (e.g., max_tokens, context_window).

Usage

get_model_info(provider, model_id)

Arguments

provider

The name of the provider.

model_id

The model ID string.

Value

A list containing all available metadata for the model, or NULL if not found.


aisdk documentation built on May 29, 2026, 9:07 a.m.