View source: R/semantic_adapter.R
| get_or_create_semantic_adapter_registry | R Documentation |
Resolve the semantic adapter registry from an environment, or create and cache a default registry when one is not already present.
get_or_create_semantic_adapter_registry(envir = NULL)
envir |
Optional environment that stores |
This helper is safe for extension packages that need to share the active semantic registry through a session or custom environment.
A SemanticAdapterRegistry object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.