| get_r_context | R Documentation |
Generates a text summary of R objects to be used as context for the LLM.
get_r_context(vars, envir = parent.frame())
vars |
Character vector of variable names to include. |
envir |
The environment to look for variables in. Default is parent.frame(). |
A single string containing the summaries of the requested variables.
if (interactive()) {
df <- data.frame(x = 1:10, y = rnorm(10))
context <- get_r_context("df")
cat(context)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.