View source: R/r_context_tools.R
| get_r_source | R Documentation |
Resolve function source text for a closure or method when available.
get_r_source(
name,
package = NULL,
method = NULL,
session = NULL,
envir = NULL,
max_lines = 120L
)
name |
Function or generic name. |
package |
Optional package/namespace name. |
method |
Optional S3 method class name. |
session |
Optional |
envir |
Optional environment. Ignored when |
max_lines |
Maximum lines to return. |
A character string source preview or structured fallback message.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.