Learn R Programming

aisdk (version 1.1.0)

model: Model Shortcut

Description

Shortcut for default model configuration. Call with no arguments to read the current default model, or pass a model to update it. This is equivalent to calling get_model() and set_model() directly.

Usage

model(new)

Value

When new is missing, returns the current default model. Otherwise invisibly returns the previous default model.

Arguments

new

Optional model identifier string or LanguageModelV1 object.

Examples

Run this code
model()
model("openai:gpt-4o-mini")
model(NULL)

Run the code above in your browser using DataLab