normalize_content_blocks: Normalize content into a list of content blocks

View source: R/content_blocks.R

normalize_content_blocksR Documentation

Normalize content into a list of content blocks

Description

Part of the companion-package extension API (used by aisdk.shiny). Coerces assorted content inputs into a normalized list of content blocks.

Usage

normalize_content_blocks(content)

Arguments

content

Content to normalize (a string, a single block, or a list of blocks).

Value

A list of normalized content blocks.


aisdk documentation built on May 29, 2026, 9:07 a.m.