View source: R/semantic_adapter.R
| register_semantic_adapter | R Documentation |
Register an adapter into a semantic adapter registry associated with a session, environment, or an explicitly provided registry.
register_semantic_adapter(
adapter,
registry = NULL,
session = NULL,
envir = NULL
)
adapter |
A |
registry |
Optional |
session |
Optional |
envir |
Optional environment. Ignored when |
Invisibly returns the registry.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.