Learn R Programming

aisdk (version 1.1.0)

request_authorization: Request User Authorization (HITL)

Description

Pauses execution and prompts the user for permission to execute a potentially risky action. Supports console environments via readline.

Usage

request_authorization(action, risk_level = "YELLOW")

Value

Logical TRUE if user permits, otherwise throws an error with the rejection reason.

Arguments

action

Character string describing the action the Agent wants to perform.

risk_level

Character string. One of "GREEN", "YELLOW", "RED".