resolve_console_startup_model: Resolve the startup model from runtime defaults and...

View source: R/console_setup.R

resolve_console_startup_modelR Documentation

Resolve the startup model from runtime defaults and .Rprofile/.Renviron

Description

Part of the companion-package extension API (used by aisdk.shiny).

Usage

resolve_console_startup_model(
  project_path = ".Renviron",
  global_path = "~/.Renviron",
  project_rprofile_path = ".Rprofile",
  global_rprofile_path = "~/.Rprofile",
  apply_profile_fn = apply_console_profile
)

Arguments

project_path, global_path, project_rprofile_path, global_rprofile_path

Paths consulted to discover a saved default model and its profile.

apply_profile_fn

Function used to apply a discovered profile.

Value

A list with model_id, source, and profile.


aisdk documentation built on May 29, 2026, 9:07 a.m.