View source: R/variable_registry.R
| sdk_protect_var | R Documentation |
Marks a variable as protected so that the Agent cannot accidentally overwrite, shadow, or deeply copy it during sandbox execution.
sdk_protect_var(name, locked = TRUE, cost = "High")
name |
Character string. The name of the variable to protect. |
locked |
Logical. If TRUE, the variable cannot be assigned to by the Agent. |
cost |
Character string. An indicator of the variable's computation/memory cost (e.g., "High", "Medium", "Low"). |
Invisible TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.