| stream_renderer | R Documentation |
Internal utilities for rendering streaming output and tool execution status in the R console using the cli package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.