Verifies a skill by running a test query against it in a sandboxed session.
test_new_skill(skill_name, test_query, registry, model)A list containing success (boolean) and result (string).
Name of the skill to test (must be in the registry).
A natural language query to test the skill (e.g., "Use hello_world to say hi").
The skill registry object.
A model object to use for the test agent.