| utils_models_update | R Documentation |
Internal utilities for synchronizing model configurations with provider APIs. When re-syncing, manually enriched fields (pricing, context, capabilities, etc.) are preserved and merged back into the updated file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.