variable_registry: Variable Registry

variable_registryR Documentation

Variable Registry

Description

Provides a mechanism to protect specific variables from being accidentally modified or duplicated by the Agent within the sandbox environment.


aisdk documentation built on May 29, 2026, 9:07 a.m.