| GenerateImageResult | R Documentation |
Result object returned by image generation and editing models.
imagesGenerated image artifacts.
textOptional textual companion output.
usageUsage information from the provider.
finish_reasonReason the model stopped generating.
warningsAny warnings from the model.
raw_responseThe raw response from the provider API.
new()Initialize a GenerateImageResult object.
GenerateImageResult$new( images = NULL, text = NULL, usage = NULL, finish_reason = NULL, warnings = NULL, raw_response = NULL )
imagesGenerated image artifacts.
textOptional text output.
usageUsage information.
finish_reasonFinish reason.
warningsWarnings.
raw_responseRaw provider response.
print()Print method for GenerateImageResult.
GenerateImageResult$print()
clone()The objects of this class are cloneable with this method.
GenerateImageResult$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.