View source: R/semantic_adapter.R
| call_object_accessor | R Documentation |
Try accessor functions in order and return the first successful result. Useful for extension authors who need compatibility across optional dependency APIs.
call_object_accessor(
obj,
fun_names,
default = NULL,
package = NULL,
args = list()
)
obj |
Object passed as the first argument to the accessor. |
fun_names |
Character vector of accessor function names to try. |
default |
Value returned when no accessor can be called successfully. |
package |
Optional package name to resolve accessors from first. |
args |
Optional named list of additional arguments passed to accessor. |
The accessor result or default.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.