| clear_error_context | R Documentation |
Clears the tracked error and warning context used by ask_ai(). This is
useful when you want to start a fresh debugging session without stale
error messages from previous operations.
clear_error_context()
Invisibly returns TRUE.
## Not run:
# Clear stale errors before starting a new debugging session
clear_error_context()
ask_ai()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.