| console | R Documentation |
Interactive terminal chat interface for ChatSession. Provides a REPL (Read-Eval-Print Loop) for conversing with LLMs. By default, enables an intelligent terminal agent that can execute commands, manage files, and run R code through natural language.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.