| content_text | R Documentation |
Creates a text content object for a multimodal message. This is kept for backward compatibility and returns the provider-neutral text block used by multimodal providers.
content_text(text)
text |
The text string. |
A list representing the text content.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.