View source: R/context_query_tools.R
| context_get | R Documentation |
Resolve a compact context handle to either its summary metadata or a bounded detailed representation.
context_get(session, handle_id, detail = c("summary", "full"))
session |
A |
handle_id |
Context handle ID. |
detail |
One of |
A list with handle metadata and optional bounded content.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.