| create_sandbox_system_prompt | R Documentation |
Generates a system prompt section that instructs the LLM how to use the R code sandbox effectively.
create_sandbox_system_prompt(sandbox)
sandbox |
A SandboxManager object. |
A character string to append to the system prompt.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.