Learn R Programming

aisdk (version 1.1.0)

create_sandbox_system_prompt: Create Sandbox System Prompt

Description

Generates a system prompt section that instructs the LLM how to use the R code sandbox effectively.

Usage

create_sandbox_system_prompt(sandbox)

Value

A character string to append to the system prompt.

Arguments

sandbox

A SandboxManager object.