View source: R/skill_registry.R
| default_skill_roots | R Documentation |
Return the standard skill search roots in increasing priority order: bundled package skills, installed user skills, project skills, then explicitly configured roots.
default_skill_roots(project_dir = getwd(), include_missing = FALSE)
project_dir |
Project directory used for project-local skill roots. |
include_missing |
If |
Character vector of skill root directories.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.