View source: R/utils_console.R
| get_last_error_for_tool | R Documentation |
Retrieves the error message from the last failure of a specific tool.
get_last_error_for_tool(tool_results, tool_name)
tool_results |
List of tool result objects |
tool_name |
Name of the tool to find the last error for |
Character string with the error message, or NULL if not found
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.