Learn R Programming

aisdk (version 1.1.0)

get_model_info: Get Full Model Info

Description

Returns the full metadata for a single model as a list. Useful for framework internals to auto-configure parameters (e.g., max_tokens, context_window).

Usage

get_model_info(provider, model_id)

Value

A list containing all available metadata for the model, or NULL if not found.

Arguments

provider

The name of the provider.

model_id

The model ID string.