View source: R/content_blocks.R
| normalize_content_blocks | R Documentation |
Part of the companion-package extension API (used by aisdk.shiny). Coerces assorted content inputs into a normalized list of content blocks.
normalize_content_blocks(content)
content |
Content to normalize (a string, a single block, or a list of blocks). |
A list of normalized content blocks.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.