Learn R Programming

aisdk (version 1.1.0)

render_text: Render Markdown Text

Description

Render markdown-formatted text in the console with beautiful styling. This function uses the same rendering engine as the streaming output, supporting headers, lists, code blocks, and other markdown elements.

Usage

render_text(text)

Value

NULL (invisibly)

Arguments

text

A character string containing markdown text, or a GenerateResult object.

Examples

Run this code
# \donttest{
if (interactive()) {
# Render simple text
render_text("# Hello\n\nThis is **bold** text.")

# Render with code block
render_text("Here is some R code:\n\n```r\nx <- 1:10\nmean(x)\n```")
}
# }

Run the code above in your browser using DataLab