Pauses execution and prompts the user for permission to execute a potentially
risky action. Supports console environments via readline.
request_authorization(action, risk_level = "YELLOW")Logical TRUE if user permits, otherwise throws an error with the rejection reason.
Character string describing the action the Agent wants to perform.
Character string. One of "GREEN", "YELLOW", "RED".