Marks a variable as protected so that the Agent cannot accidentally overwrite, shadow, or deeply copy it during sandbox execution.
sdk_protect_var(name, locked = TRUE, cost = "High")Invisible TRUE.
Character string. The name of the variable to protect.
Logical. If TRUE, the variable cannot be assigned to by the Agent.
Character string. An indicator of the variable's computation/memory cost (e.g., "High", "Medium", "Low").