| tool_result_message | R Documentation |
Create a message representing the result of a tool call. Used to send tool execution results back to the LLM.
tool_result_message(tool_call_id, result, is_error = FALSE)
tool_call_id |
The ID of the tool call this result responds to. |
result |
The result content (will be converted to string if needed). |
is_error |
If TRUE, indicates this result is an error message. |
A list representing a tool result message.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.