Create a message representing the result of a tool call. Used to send tool execution results back to the LLM.
tool_result_message(tool_call_id, result, is_error = FALSE)A list representing a tool result message.
The ID of the tool call this result responds to.
The result content (will be converted to string if needed).
If TRUE, indicates this result is an error message.