| variable_registry | R Documentation |
Provides a mechanism to protect specific variables from being accidentally modified or duplicated by the Agent within the sandbox environment.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.