Learn R Programming

aisdk (version 1.1.0)

variable_registry: Variable Registry

Description

Provides a mechanism to protect specific variables from being accidentally modified or duplicated by the Agent within the sandbox environment.

Arguments